@@ -138,7 +138,7 @@ Set, you're limited to numbers less than 400,000 (although you could make
 
 =head1 AUTHOR
 
-brian d foy C<< <brian.d.foy@gmail.com> >> 2011-
+brian d foy C<< <brian.d.foy@gmail.com> >>
 
 This module started with the Roman module, credited to:
 
@@ -148,7 +148,7 @@ Alexandr Ciornii, C<< <alexchorny at gmail.com> >> 2007
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011, brian d foy.
+Copyright © 2011-2016, brian d foy <bdfoy@cpan.org>.
 
 You can use this module under the same terms as Perl itself.
 
@@ -160,11 +160,10 @@ package Roman::Unicode {
 	use strict;
 	use warnings;
 	use open IO => ':utf8';
-	use vars qw( $VERSION @EXPORT_OK );
 
 	use Exporter 'import';
-	@EXPORT_OK = qw( is_roman to_perl to_roman to_ascii );
-	$VERSION = '1.03';
+	our @EXPORT_OK = qw( is_roman to_perl to_roman to_ascii );
+	our $VERSION = '1.031';
 
 	use Unicode::UCD;
 	use Unicode::Normalize qw(NFKD);
